gradoptics.light\_sources.base\_light\_source
=========================================

.. automodule:: gradoptics.light_sources.base_light_source
   :members:
   :undoc-members:
   :show-inheritance:
